;; https://shadow-cljs.github.io/docs/UsersGuide.html#Leiningen
(defproject cli "0.13.2"
  :description "Runops command line"
  :url "https://github.com/runopsio/cli"
  :dependencies [[org.clojure/clojure "1.10.1"]
                 [http-kit "2.3.0"]
                 [cljs-http "0.1.45"]
                 [org.clojure/core.async "1.3.610"]
                 [org.clojure/clojurescript "1.10.758" :scope "provided"]
                 [macchiato/core "0.2.16"]
                 [thheller/shadow-cljs "2.11.23"]
                 [lein-cljfmt "0.8.0"]
                 [clj-kondo "2021.08.06"]]
  :source-paths ["src/main" "src/test"]
  :aliases {"clj-kondo" ["trampoline" "run" "-m" "clj-kondo.main"]}
  :plugins [[lein-cljfmt "0.8.0"]
            [lein-shadow "0.3.0"]]

  ;; https://github.com/technomancy/leiningen/wiki/Faster#disable-bytecode-verification
  :jvm-opts ["-Xverify:none"]
  :cljfmt
  {:remove-consecutive-blank-lines? true}

  ;; https://gitlab.com/nikperic/lein-shadow
  :shadow-cljs
  {:builds
   {:cli
    {:target :node-script
     :main core/main
     ;; TODO: remove this option to get better optimizations (it's breaking without it)
     :compiler-options {:source-maps true
                        :source-map-detail-level :all
                        :pretty-print true
                        :pseudo-names true
                        :optimizations :simple
                        :infer-externs false}
     :output-to "out/runops.js"
     :devtools {:repl-init-ns core
                :repl-pprint true}}
    :test
    {:target :node-test
     :output-to "out/runops-tests.js"
     :compiler-options {:optimizations :simple :infer-externs false}
     :autorun true}}})
