(ns auth
  (:require [cljs.nodejs :as node]
            [traces :as traces]))

(def crypto (node/require "crypto"))

(defn node-slurp [path]
  (let [fs (node/require "fs")]
    (.readFileSync fs path "utf8")))

(defn shasum [k digest]
  (-> crypto
      (.createHash "sha256")
      (.update k)
      (.digest digest)))

(defn get-key []
  (try
    (let [key (node-slurp (str (.-HOME node/process.env) "/.runops/config"))]
      (traces/add-context {:user (shasum key "hex")})
      key)
    (catch js/Error e (js/console.log (.toString e)))))

(defn key-auth [data]
  (when-let [key (get-key)]
    (assoc data :key key)))
