(ns version
  (:require-macros [cljs.core.async.macros :refer [go]])
  (:require [cljs.nodejs :as node]
            [client :as client]
            [spinner :as spinner]
            [cljs.core.async :refer [<!]]))

(def Table (node/require "cli-table"))
(def colors (node/require "colors/safe"))
(def pjson (node/require "../package.json"))
(def crypto (node/require "crypto"))

(defn sha1sum [data]
  (-> (.createHash crypto "sha1")
      (.update data)
      (.digest "hex")))

(defn message [old-version new-version]
  (str "Update available " (.gray colors old-version) " -> " (.green colors new-version) "\n"
       "Run " (.cyan colors "npm install -g runops") " to update"))

(defn message-table [message]
  (let [t (Table. (clj->js {:style {:border ["yellow"]}}))]
    (.push t (clj->js [message]))
    (.toString t)))

(defn get-current-version
  "retrieves the current version from local package.json" []
  (.-version pjson))

(defn print-update-version-message
  "if the latest version is greater than the current version,
   print a message informing there's an available update."
  []
  (go (let [current-version (get-current-version)
            response (<! (client/get-npm-version))
            npm-version (or (-> response :body :version) current-version)]
        (when (not (= (sha1sum npm-version)
                      (sha1sum current-version)))
          ;; this is necessary to prevent spinner breaking the output of
          ;; the update version message
          (spinner/stop nil)
          (js/console.log
           (message-table (message current-version npm-version)))))))
